#[repr(u8)]pub enum Outcfg {
RETAIN_LASTVALUE = 0,
TRISTATED = 1,
}Variants
RETAIN_LASTVALUE = 0
Output data retains last value when chip select is negated
TRISTATED = 1
Output data is tristated when chip select is negated
Implementations